Computes the eigenvalue of the n x n, row-major matrix a nearest to shift (and a
corresponding unit-length eigenvector, written into out_eigenvector) by inverse power
iteration: power iteration applied to the operator (a - shift * I)⁻¹.
Computes the dominant (largest-magnitude) eigenvalue of the n x n, row-major matrix a
by power iteration, returning the eigenvalue and writing a corresponding unit-length
eigenvector into out_eigenvector.